====
SNDV
====
This package provides encoding and decoding for Self-Delimiting Numeric Values as defined in RFC6256.

Usage
=====
**TODO**


Acknowledgements
================
This code borrows heavily from the example in RFC6256.